==> zio-aws-mgn_2.13-5.20.7.2-sources.jar: zio/aws/mgn/model/ArchiveApplicationRequest.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.mgn.model.primitives.ApplicationID
import scala.jdk.CollectionConverters._
final case class ArchiveApplicationRequest(applicationID: ApplicationID) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest = {
    import ArchiveApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
      .builder()
      .applicationID(ApplicationID.unwrap(applicationID): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.ArchiveApplicationRequest.ReadOnly =
    zio.aws.mgn.model.ArchiveApplicationRequest.wrap(buildAwsValue())
}
object ArchiveApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.ArchiveApplicationRequest =
      zio.aws.mgn.model.ArchiveApplicationRequest(applicationID)
    def applicationID: ApplicationID
    def getApplicationID: ZIO[Any, Nothing, ApplicationID] =
      ZIO.succeed(applicationID)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
  ) extends zio.aws.mgn.model.ArchiveApplicationRequest.ReadOnly {
    override val applicationID: ApplicationID =
      zio.aws.mgn.model.primitives.ApplicationID(impl.applicationID())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
  ): zio.aws.mgn.model.ArchiveApplicationRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mgn_2.13-7.21.15.4-sources.jar: zio/aws/mgn/model/ArchiveApplicationRequest.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.mgn.model.primitives.{ApplicationID, AccountID}
import scala.jdk.CollectionConverters._
final case class ArchiveApplicationRequest(
    accountID: Optional[AccountID] = Optional.Absent,
    applicationID: ApplicationID
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest = {
    import ArchiveApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
      .builder()
      .optionallyWith(
        accountID.map(value => AccountID.unwrap(value): java.lang.String)
      )(_.accountID)
      .applicationID(ApplicationID.unwrap(applicationID): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.ArchiveApplicationRequest.ReadOnly =
    zio.aws.mgn.model.ArchiveApplicationRequest.wrap(buildAwsValue())
}
object ArchiveApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.ArchiveApplicationRequest =
      zio.aws.mgn.model
        .ArchiveApplicationRequest(accountID.map(value => value), applicationID)
    def accountID: Optional[AccountID]
    def applicationID: ApplicationID
    def getAccountID: ZIO[Any, AwsError, AccountID] =
      AwsError.unwrapOptionField("accountID", accountID)
    def getApplicationID: ZIO[Any, Nothing, ApplicationID] =
      ZIO.succeed(applicationID)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
  ) extends zio.aws.mgn.model.ArchiveApplicationRequest.ReadOnly {
    override val accountID: Optional[AccountID] = zio.aws.core.internal
      .optionalFromNullable(impl.accountID())
      .map(value => zio.aws.mgn.model.primitives.AccountID(value))
    override val applicationID: ApplicationID =
      zio.aws.mgn.model.primitives.ApplicationID(impl.applicationID())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.ArchiveApplicationRequest
  ): zio.aws.mgn.model.ArchiveApplicationRequest.ReadOnly = new Wrapper(impl)
}
